@@ -152,7 +152,7 @@ for name in sorted(basicklassmap):
     # and virDomainSnapshot namespaces which stupidly used a different
     # convention which we now can't fix without breaking API
     if func[0:3] == "Get" and klass not in ["virConnect", "virDomainSnapshot", "libvirt"]:
-        if func not in ["GetCPUStats"]:
+        if func not in ["GetCPUStats", "GetTime"]:
             func = func[3:]
 
     # The object creation and lookup APIs all have to get re-mapped
@@ -207,6 +207,8 @@ for name in sorted(basicklassmap):
     func = func[0:1].lower() + func[1:]
     if func[0:8] == "nWFilter":
         func = "nwfilter" + func[8:]
+    if func[0:8] == "fSFreeze" or func[0:6] == "fSThaw":
+        func = "fs" + func[2:]
 
     # ...except when they don't. More stupid naming
     # decisions we can't fix
